package
Version:
v0.0.0-...-864b3e4
Opens a new window with list of versions in this module.
Published: Nov 11, 2016
License: MIT
Opens a new window with license information.
Imports: 8
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Client interface {
scepserver.Service
Supports(string) bool
}
Client implements the SCEP service and extra methods
NewClient returns a SCEP service that's backed by the provided Endpoint
Source Files
¶
Click to show internal directories.
Click to hide internal directories.